==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AFloatBaseType.h <==
// public final class soot.jimple.parser.node.AFloatBaseType

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ba59cedefe3f694e soot_jimple_parser_node_AFloatBaseType
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 5816fe0bb21d8c7b soot_jimple_parser_node_PBaseType

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseType

#include "soot/jimple/parser/node/PBaseType.h"

#ifndef _JC_soot_jimple_parser_node_AFloatBaseType_H_
#define _JC_soot_jimple_parser_node_AFloatBaseType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TFloat$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AFloatBaseType$sub_refs	_jc_soot_jimple_parser_node_AFloatBaseType$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AFloatBaseType$sub_nonrefs	_jc_soot_jimple_parser_node_AFloatBaseType$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AFloatBaseType$refs	_jc_soot_jimple_parser_node_AFloatBaseType$refs;
typedef struct _jc_soot_jimple_parser_node_AFloatBaseType$nonrefs	_jc_soot_jimple_parser_node_AFloatBaseType$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AFloatBaseType$object	_jc_soot_jimple_parser_node_AFloatBaseType$object;

typedef const struct _jc_soot_jimple_parser_node_AFloatBaseType$vmethods	_jc_soot_jimple_parser_node_AFloatBaseType$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AFloatBaseType$vtable	_jc_soot_jimple_parser_node_AFloatBaseType$vtable;
typedef const struct _jc_soot_jimple_parser_node_AFloatBaseType$vtype	_jc_soot_jimple_parser_node_AFloatBaseType$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AFloatBaseType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseType$object *);
extern void _jc_soot_jimple_parser_node_AFloatBaseType$method$_init$e1e143cccc9a37c8(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseType$object *, struct _jc_soot_jimple_parser_node_TFloat$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AFloatBaseType$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseType$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AFloatBaseType$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseType$object *);
extern struct _jc_soot_jimple_parser_node_TFloat$object *_jc_soot_jimple_parser_node_AFloatBaseType$method$getFloat$d211374daf9e7e23(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseType$object *);
extern void _jc_soot_jimple_parser_node_AFloatBaseType$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AFloatBaseType$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AFloatBaseType$method$setFloat$0886c6c085d53d50(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseType$object *, struct _jc_soot_jimple_parser_node_TFloat$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AFloatBaseType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseType$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AFloatBaseType$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AFloatBaseType$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AFloatBaseType$method_info$getFloat$d211374daf9e7e23;
extern _jc_method _jc_soot_jimple_parser_node_AFloatBaseType$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AFloatBaseType$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AFloatBaseType$method_info$setFloat$0886c6c085d53d50;
extern _jc_method _jc_soot_jimple_parser_node_AFloatBaseType$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AFloatBaseType$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseType$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseType$object *);
	struct _jc_soot_jimple_parser_node_TFloat$object	*(*getFloat$d211374daf9e7e23)(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseType$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setFloat$0886c6c085d53d50)(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseType$object *, struct _jc_soot_jimple_parser_node_TFloat$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseType$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AFloatBaseType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseType$vmethods	soot_jimple_parser_node_PBaseType;
	_jc_soot_jimple_parser_node_AFloatBaseType$vmethods	soot_jimple_parser_node_AFloatBaseType;
};

// Vtype
struct _jc_soot_jimple_parser_node_AFloatBaseType$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AFloatBaseType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AFloatBaseType$sub_refs {
	struct _jc_soot_jimple_parser_node_TFloat$object	*__5ffloat__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AFloatBaseType$refs {
    _jc_soot_jimple_parser_node_AFloatBaseType$sub_refs	soot_jimple_parser_node_AFloatBaseType;
    _jc_soot_jimple_parser_node_PBaseType$sub_refs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AFloatBaseType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AFloatBaseType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseType$sub_nonrefs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_AFloatBaseType$sub_nonrefs	soot_jimple_parser_node_AFloatBaseType;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AFloatBaseType$object {
	_jc_soot_jimple_parser_node_AFloatBaseType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AFloatBaseType$vtype	*vtype;
	_jc_soot_jimple_parser_node_AFloatBaseType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AFloatBaseType$vtype _jc_soot_jimple_parser_node_AFloatBaseType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AFloatBaseType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AFloatBaseType$class_object;

#endif	/* _JC_soot_jimple_parser_node_AFloatBaseType_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AFloatBaseType.h <==
// public final class soot.jimple.parser.node.AFloatBaseType

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ba59cedefe3f694e soot_jimple_parser_node_AFloatBaseType
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 5816fe0bb21d8c7b soot_jimple_parser_node_PBaseType

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseType

#include "soot/jimple/parser/node/PBaseType.h"

#ifndef _JC_soot_jimple_parser_node_AFloatBaseType_H_
#define _JC_soot_jimple_parser_node_AFloatBaseType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TFloat$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AFloatBaseType$sub_refs	_jc_soot_jimple_parser_node_AFloatBaseType$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AFloatBaseType$sub_nonrefs	_jc_soot_jimple_parser_node_AFloatBaseType$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AFloatBaseType$refs	_jc_soot_jimple_parser_node_AFloatBaseType$refs;
typedef struct _jc_soot_jimple_parser_node_AFloatBaseType$nonrefs	_jc_soot_jimple_parser_node_AFloatBaseType$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AFloatBaseType$object	_jc_soot_jimple_parser_node_AFloatBaseType$object;

typedef const struct _jc_soot_jimple_parser_node_AFloatBaseType$vmethods	_jc_soot_jimple_parser_node_AFloatBaseType$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AFloatBaseType$vtable	_jc_soot_jimple_parser_node_AFloatBaseType$vtable;
typedef const struct _jc_soot_jimple_parser_node_AFloatBaseType$vtype	_jc_soot_jimple_parser_node_AFloatBaseType$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AFloatBaseType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AFloatBaseType$method$_init$e1e143cccc9a37c8(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseType$object *, struct _jc_soot_jimple_parser_node_TFloat$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AFloatBaseType$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseType$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AFloatBaseType$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseType$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TFloat$object *_jc_soot_jimple_parser_node_AFloatBaseType$method$getFloat$d211374daf9e7e23(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AFloatBaseType$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AFloatBaseType$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AFloatBaseType$method$setFloat$0886c6c085d53d50(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseType$object *, struct _jc_soot_jimple_parser_node_TFloat$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AFloatBaseType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseType$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AFloatBaseType$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AFloatBaseType$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AFloatBaseType$method_info$getFloat$d211374daf9e7e23;
extern _jc_method _jc_soot_jimple_parser_node_AFloatBaseType$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AFloatBaseType$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AFloatBaseType$method_info$setFloat$0886c6c085d53d50;
extern _jc_method _jc_soot_jimple_parser_node_AFloatBaseType$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AFloatBaseType$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseType$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseType$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TFloat$object	*(*getFloat$d211374daf9e7e23)(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseType$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setFloat$0886c6c085d53d50)(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseType$object *, struct _jc_soot_jimple_parser_node_TFloat$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AFloatBaseType$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AFloatBaseType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseType$vmethods	soot_jimple_parser_node_PBaseType;
	_jc_soot_jimple_parser_node_AFloatBaseType$vmethods	soot_jimple_parser_node_AFloatBaseType;
};

// Vtype
struct _jc_soot_jimple_parser_node_AFloatBaseType$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AFloatBaseType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AFloatBaseType$sub_refs {
	struct _jc_soot_jimple_parser_node_TFloat$object	*__5ffloat__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AFloatBaseType$refs {
    _jc_soot_jimple_parser_node_AFloatBaseType$sub_refs	soot_jimple_parser_node_AFloatBaseType;
    _jc_soot_jimple_parser_node_PBaseType$sub_refs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AFloatBaseType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AFloatBaseType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseType$sub_nonrefs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_AFloatBaseType$sub_nonrefs	soot_jimple_parser_node_AFloatBaseType;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AFloatBaseType$object {
	_jc_soot_jimple_parser_node_AFloatBaseType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AFloatBaseType$vtype	*vtype;
	_jc_soot_jimple_parser_node_AFloatBaseType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AFloatBaseType$vtype _jc_soot_jimple_parser_node_AFloatBaseType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AFloatBaseType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AFloatBaseType$class_object;

#endif	/* _JC_soot_jimple_parser_node_AFloatBaseType_H_ */
